@@ -18,7 +18,7 @@ package GCExportImport;
 #
 #  You should have received a copy of the GNU General Public License
 #  along with GCstar; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 #
 ###################################################
 
@@ -426,7 +426,8 @@ use GCDialogs;
             $self->{optionsTable}->attach($self->{fieldsSelection},
                                           0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
             $self->{fieldsSelection}->signal_connect('clicked' => sub {
-                $self->{fieldsDialog}->show;
+                $self->{fields} = $self->{fieldsDialog}->getSelectedIds
+                    if $self->{fieldsDialog}->show;
             });
             $row++;
         }
