@@ -1,4 +1,4 @@
-package GCImageLists;
+﻿package GCImageLists;
 
 ###################################################
 #
@@ -1424,7 +1424,7 @@ my $timeOutBetweenEnhancements = 50;
             if ($^O =~ /win32/i)
             {
                 # It looks like Win32 version only supports JPEG pictures for background
-                $tmpPixbuf->save($self->{style}->{tmpBgPixmap}, 'jpeg', quality => '100');
+                $tmpPixbuf->save($self->{style}->{tmpBgPixmapFile}, 'jpeg', quality => '100');
             }
             else
             {
