@@ -2,14 +2,16 @@ package GCPlugins::GCfilms::GCImdb;
 
 ###################################################
 #
-#  Copyright 2010 groms
-#
 #  Features:
 #  + Multiple directors separated by comma
 #  + Multiple countries separated by comma
 #  + Correct URL in case of redirection
 #  + Fetches Original Title
 #
+###################################################
+#
+#  Copyright 2005-2014 Christian Jodar
+#
 #  This file is part of GCstar.
 #
 #  GCstar is free software; you can redistribute it and/or modify
@@ -24,7 +26,7 @@ package GCPlugins::GCfilms::GCImdb;
 #
 #  You should have received a copy of the GNU General Public License
 #  along with GCstar; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 #
 ###################################################
 
@@ -104,6 +106,13 @@ use GCPlugins::GCfilms::GCfilmsCommon;
                 {
                     $self->{insideOriginalTitle} = 1;
                 }
+                elsif ($self->{insideCastList})
+                {
+                    if ($attr->{itemprop} eq 'name')
+                    {
+                        $self->{insideActor} = 1;
+                    }
+                }
             }
             elsif ($tagname eq "img")
             {
@@ -140,11 +149,11 @@ use GCPlugins::GCfilms::GCfilmsCommon;
             {
                 if ($self->{insideCastList})
                 {
-                    if ($attr->{class} eq 'name')
-                    {
-                        $self->{insideActor} = 1;
-                    }
-                    elsif ($attr->{class} eq 'character')
+                    #if ($attr->{class} eq 'name')
+                    #{
+                        #$self->{insideActor} = 1;
+                    #}
+                   if ($attr->{class} eq 'character')
                     {
                         $self->{insideRole} = 1;
                     }
@@ -236,7 +245,8 @@ use GCPlugins::GCfilms::GCfilmsCommon;
         
         if ($self->{parsingList})
         {
-            if ($self->{inside}->{h1} && $origtext !~ m/IMDb\s*Title\s*Search/i)
+            #if ($self->{inside}->{h1} && $origtext !~ m/IMDb\s*Title\s*Search/i)
+            if ($self->{inside}->{title} && $origtext !~ m/Find\s-\sIMDb/i)
             {
                 $self->{parsingEnded} = 1;
                 $self->{itemIdx} = 0;
